/***경제활동상태 변수 만들기***/ 

clear
cd "D:\klips\Stata"

use klips22p, replace 

/**현재 일자리의 종사상 지위 (empst)**/

// p**0314: 종사상지위 (1=상용, 2=임시, 3=일용 , 4=고용주/자영업자, 5=무급가족종사자)

gen empst=p220314
tab empst
lab var empst "종사상지위(1:임금근로자,2:비임금근로자,3:미취업자,4:비경제활동인구)"


/**임금근로자/비임금근로자/실업자/비경제활동인구**/ 

// jobclass: 일자리유형
// p**2801: 지난 1주일간 구직여부
// p**2802: 지난 1개월간 구직여부
// p**2806: 취업가증성여부

/*OECD,경활 기준 (econ1)*/ 

gen econ1 = 4 
replace econ1 =1 if jobclass == 1 | jobclass ==5   
replace econ1 =2 if jobclass == 3 | jobclass ==7   
replace econ1 =3 if (p222801 == 1 | p222802==1) & p222806==1 
tab econ1
lab var econ1 "1)임금근로자,2)비임금근로자,3)실업자(OECD,경활기준),4)비경제활동인구"

/*ILO 기준 (econ2)*/ 

gen econ2 = 4 
replace econ2 =1 if jobclass == 1 | jobclass ==5  
replace econ2 =2 if jobclass == 3 | jobclass ==7   
replace econ2 =3 if p222801==1 & p222806==1 
tab econ2
lab var econ2 "1)임금근로자,2)비임금근로자,3)실업자(ILO기준),4)비경제활동인구"


/**경제활동인구/비경제활동인구**/ 

// 방법1 //
recode econ1(1/3=1)(4=0), gen(econst1) 
tab econst1 
lab var econst1 "1)경제활동인구,2)비경제활동인구"

// 방법2 //
gen econst2 =(econ1 >= 1 & econ1 <=3)  
tab econst2 
lab var econst2 "1)경제활동인구,2)비경제활동인구"


/*취업자/실업자(emp)*/ 
recode econ1(1/2=1)(3=2)(4=.), gen(emp) // 경활 중 취업여부 더미 변수 만들기 
tab emp 
lab var emp "1)취업자,2)실업자"


/*고용원이 있는 자영업자/고용원이 없는 자영업자(self)*/ 

// p**0409: 종업원 유무(비임금)

gen self=1 if empst==4   
replace self=2 if empst==4 & p220409==2  
tab self 
lab var self "1)고용원이 있는 자영업자,2)고용원이 없는 자영업자"


save "D:\klips\Stata\data\exaple.dta", replace 




